@@ -1,3 +1,4 @@
+import contextlib
 import json
 import logging
 import os
@@ -129,12 +130,12 @@ def sub_resource_level(current_class, owner_class, parent_class):
     # return the name of the last class in MRO list that is not one of base
     # classes; otherwise return None
     for class_iterator in reversed(
-        list(
+        [
             class_iterator
             for class_iterator in current_class.mro()
             if class_iterator not in owner_class.mro()
             and issubclass(class_iterator, parent_class)
-        )
+        ]
     ):
         return class_iterator.__name__
 
@@ -153,12 +154,10 @@ class KubeAPIVersion(Version):
         super().__init__(vstring=vstring)
 
     def parse(self, vstring):
-        components = [x for x in self.component_re.split(vstring) if x]
-        for i, obj in enumerate(components):
-            try:
-                components[i] = int(obj)
-            except ValueError:
-                pass
+        components = [comp for comp in self.component_re.split(vstring) if comp]
+        for idx, obj in enumerate(components):
+            with contextlib.suppress(ValueError):
+                components[idx] = int(obj)
 
         errmsg = f"version '{vstring}' does not conform to kubernetes api versioning guidelines"
 
@@ -200,7 +199,7 @@ class KubeAPIVersion(Version):
             return 1
 
 
-class classproperty(object):  # noqa: N801
+class ClassProperty:
     def __init__(self, func):
         self.func = func
 
@@ -214,7 +213,7 @@ class ValueMismatch(Exception):
     """
 
 
-class Resource(object):
+class Resource:
     """
     Base class for API resources
     """
@@ -369,7 +368,7 @@ class Resource(object):
         self.teardown = teardown
         self.timeout = timeout
 
-    @classproperty
+    @ClassProperty
     def kind(cls):  # noqa: N805
         return sub_resource_level(cls, NamespacedResource, Resource)
 
@@ -432,7 +431,14 @@ class Resource(object):
             kind=cls.kind, api_version=cls.api_version, **get_kwargs
         ).get(*args, **kwargs)
 
-    def api(self, **kwargs):
+    def _prepare_singular_name_kwargs(self, **kwargs):
+        kwargs = kwargs if kwargs else {}
+        if self.singular_name:
+            kwargs["singular_name"] = self.singular_name
+
+        return kwargs
+
+    def full_api(self, **kwargs):
         """
         Get resource API
 
@@ -451,12 +457,16 @@ class Resource(object):
         Returns:
             Resource: Resource object.
         """
-        if self.singular_name:
-            kwargs["singular_name"] = self.singular_name
+        kwargs = self._prepare_singular_name_kwargs(**kwargs)
+
         return self.client.resources.get(
             api_version=self.api_version, kind=self.kind, **kwargs
         )
 
+    @property
+    def api(self):
+        return self.full_api()
+
     def wait(self, timeout=TIMEOUT, sleep=1):
         """
         Wait for resource
@@ -537,7 +547,7 @@ class Resource(object):
             wait_timeout=timeout,
             sleep=sleep,
             exceptions=ProtocolError,
-            func=self.api().get,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -591,17 +601,14 @@ class Resource(object):
 
         LOGGER.info(f"Posting {data}")
         LOGGER.info(f"Create {self.kind} {self.name}")
-        res = self.api().create(body=data, namespace=self.namespace)
+        res = self.api.create(body=data, namespace=self.namespace)
         if wait and res:
             return self.wait()
         return res
 
     def delete(self, wait=False, timeout=TIMEOUT, body=None):
-        resource_list = self.api()
         try:
-            res = resource_list.delete(
-                name=self.name, namespace=self.namespace, body=body
-            )
+            res = self.api.delete(name=self.name, namespace=self.namespace, body=body)
         except NotFoundError:
             return False
 
@@ -631,7 +638,7 @@ class Resource(object):
             resource_dict: Resource dictionary
         """
         LOGGER.info(f"Update {self.kind} {self.name}: {resource_dict}")
-        self.api().patch(
+        self.api.patch(
             body=resource_dict,
             namespace=self.namespace,
             content_type="application/merge-patch+json",
@@ -643,7 +650,7 @@ class Resource(object):
         Use this to remove existing field. (update() will only update existing fields)
         """
         LOGGER.info(f"Replace {self.kind} {self.name}: {resource_dict}")
-        self.api().replace(body=resource_dict, name=self.name, namespace=self.namespace)
+        self.api.replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
     def _retry_cluster_exceptions(func):
@@ -692,7 +699,7 @@ class Resource(object):
         """
 
         def _instance():
-            return self.api().get(name=self.name)
+            return self.api.get(name=self.name)
 
         return self._retry_cluster_exceptions(func=_instance)
 
@@ -725,7 +732,7 @@ class Resource(object):
             wait_timeout=timeout,
             sleep=1,
             exceptions=ProtocolError,
-            func=self.api().get,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -841,7 +848,7 @@ class NamespacedResource(Resource):
         Returns:
             openshift.dynamic.client.ResourceInstance
         """
-        return self.api().get(name=self.name, namespace=self.namespace)
+        return self.api.get(name=self.name, namespace=self.namespace)
 
     def _base_body(self):
         res = super(NamespacedResource, self)._base_body()
@@ -862,7 +869,7 @@ class NamespacedResource(Resource):
         return self._base_body()
 
 
-class ResourceEditor(object):
+class ResourceEditor:
     def __init__(self, patches, action="update", user_backups=None):
         """
         Args:
